<template>
  <div class="container p-2 pb-5 mb-5">
    <!-- هدر -->
    <div class="text-center mb-3 py-5 bg-light rounded-3" v-if="typeof route.query.status !== 'undefined'">
      <div class="header-content">
        <div class="mb-3">
          <i class="icon icon-regular-check-circle text-success fs-1"></i>
        </div>
        <h4 class="mb-3">{{ t('account.business.upgrade.success_title') }}</h4>
        <p class="text-muted">{{ t('account.business.upgrade.success_subtitle') }}</p>
      </div>
    </div>

    <!-- پلن‌ها -->
    <div class="plans-container d-grid gap-3 mb-4">
      <div
          v-for="(packageItem,index) in data.packages"
          :key="index"
          class="plan-card rounded-3 p-4 shadow-sm position-relative d-flex align-items-start flex-column cursor-pointer"
          :class="[{ selected: data.selected.includes(packageItem.id) },{'disable-item': packageItem.slug === 'payment'}]"
          @click="selectPackage(index)"
      >
        <div class="plan-header mb-3 pb-2 border-bottom d-flex align-items-center justify-content-between w-100">
          <h5>{{ packageItem.title }}</h5>
          <div class="d-flex align-items-baseline gap-2">
            <span class="font-size-18 fw-bold">{{ formatPrice(packageItem.price, packageItem.discount) }}</span>
            <span class="font-size-13 text-muted fw-bold">تومان</span>
          </div>
        </div>
        <div class="plan-description">
          <p class="text-muted font-size-14">
            {{ packageItem.description }}
          </p>
        </div>
        <button class="select-btn w-100 p-3 border-0 rounded-3 bg-light text-secondary fw-bold cursor-pointer mt-auto">
          <template v-if="!data.selected.includes(packageItem.id)">
            {{ t('account.business.upgrade.select_button') }}
          </template>
          <template v-else>
            {{ t('account.business.upgrade.selected_button') }}
          </template>
        </button>
      </div>
    </div>


    <!-- روش پرداخت -->
    <div class="payment-section rounded-3 p-4 shadow-sm">
      <h5 class="fw-bold mb-4 d-flex align-items-center justify-content-between">
        <span v-if="data.selected.length > 0" class="font-size-16 text-muted">
          {{ t('account.business.upgrade.pay_button') }}
        </span>
        <span class="font-size-16 text-muted">{{ totalPrice.toLocaleString() }} {{ t('global.currency') }}</span>
      </h5>
      <h5 class="fw-bold mb-4 d-flex font-size-14 align-items-center justify-content-between">
        <span>{{ t('account.business.upgrade.payment_method') }}</span>
      </h5>

      <div class="d-flex flex-column gap-2 mb-5">
        <!-- کیف پول -->
        <div
            class="payment-option d-flex align-items-center p-3 rounded-3 border cursor-pointer position-relative"
            :class="[{active: data.wallet_status}]"
            @click="paymentWallet"
        >
          <div class="option-icon ms-2">
            <i class="icon icon-regular-wallet"></i>
          </div>
          <div class="option-details flex-grow-1">
            <span class="fw-bold d-block mb-1">{{ t('account.business.upgrade.wallet') }}</span>
            <small class="font-size-12 text-muted">
              {{ t('account.business.upgrade.wallet_balance', {amount: data.wallet.balance}) }}
            </small>
          </div>
        </div>
      </div>

      <button
          class="payment-btn w-100 p-3 border-0 rounded-3 btn-default btn fw-bold cursor-pointer d-flex align-items-center justify-content-center"
          :disabled="data.selected.length === 0"
          :class="{'btn-loading': data.loaded}"
          @click="submitPayment"
      >
        <template v-if="data.selected.length > 0">
          <template v-if="!data.loaded">
            <span>{{ t('account.business.upgrade.pay') }}</span>
          </template>
          <template v-else>
            <span class="spinner-border spinner-border-sm me-2" role="status" aria-hidden="true"></span>
            {{ t("wallet.charge_section.processing") }}
          </template>
        </template>
        <template v-else>
          <span>{{ t('account.business.upgrade.no_plan_selected') }}</span>
        </template>
      </button>
    </div>
  </div>
  <modal-payment v-model:show="data.show" :url="data.url"/>
</template>

<script setup>
import {useI18n} from 'vue-i18n'
import {onMounted, ref, computed, reactive} from 'vue'
import {useNuxtApp, useCookie} from '#imports'
import {useRoute,useRouter} from "vue-router";

const route = useRoute();
const router = useRouter();

const {t} = useI18n()
const {$api,$sweetalert} = useNuxtApp()
const token = useCookie('token');
const business_id = ref(route.params.id);

const data = reactive({
  loaded: false,
  show: false,
  business: {},
  url: '',
  wallet_status: 0,
  wallet: {
    balance: 0
  },
  selected: [],
  packages: []
});

const getData = async () => {
  await $api.post('/user/business/show',{id: business_id.value}).then((value) => {
    if(value.data.data.role == 'user') {
      router.push('/account/business')
    }
    data.business = value.data.data;
    if(data.business.status.id == '0') {
      data.selected.push(0)
    }
  });
}

const selectPackage = (index) => {
  if (data.selected.includes(data.packages[index].id)) {
    data.selected = data.selected.filter(id => id !== data.packages[index].id)
  } else {
    data.selected.push(data.packages[index].id)
  }
}

const totalPrice = computed(() => {
  return data.packages.reduce((sum, packageItem) => {
    if (data.selected.includes(packageItem.id)) {
      return sum + Number(packageItem.discount || packageItem.price || 0)
    }
    return sum
  }, 0)
})

const formatPrice = (price, discount) => {
  const value = Number(discount || price || 0)
  return value.toLocaleString()
}

const getWallet = async () => {
  await $api.post('/user/wallet', {}, {
    headers: {
      Authorization: `Bearer ${token.value}`
    }
  }).then((value) => {
    if (value.data.status) {
      data.wallet = value.data.data;
    }
  })
}

const getPackages = async () => {
  await $api.post('/package', {
    business_id: business_id.value,
    type: 'business'
  }).then((value) => {
    if (value.data.status) {
      data.packages = []
      if(data.business.status.id == '0') {
        data.packages = [{
          id: 0,
          title: 'پرداخت پایه',
          price: '100000',
          slug: "payment",
          discount: null,
          description: 'با پرداخت مبلغ کسب و کار میتوانید از امکانات بخش کسب و کارا بهره مند شوید.'
        },...value.data.data];
      }else {
        data.packages = [...value.data.data];
      }
    }
  })
}

const submitPayment = async () => {
  data.loaded = true;
  await $api.post('/payment', {
    business_id: business_id.value,
    wallet: data.wallet_status,
    packages: data.selected,
    platform: 'app'
  }, {
    headers: {
      Authorization: `Bearer ${useCookie('token').value}`
    }
  }).then((value) => {
    if (value.data?.status) {
      if(typeof value.data.data.url !== 'undefined') {
        data.url = value.data.data.url;
        data.show = true;
        data.loaded = false;
      }else {
        if(value.data.data.payment) {
          $sweetalert.success('پرداخت با موفقیت انجام شد.');
          getWallet();

          setTimeout(() => {
            router.push('/account/business');
          },1000)
        }
      }
    }
  })
}

const paymentWallet = () => {
  data.wallet_status = data.wallet_status ? 0 : 1;
}

onMounted(() => {
  getData();
  getWallet().then(() => {
    getPackages()
  })
})

</script>

<style scoped>
.plans-container {
  grid-template-columns: repeat(auto-fit, minmax(280px, 1fr));
}

.plan-card {
  transition: all 0.3s;
  border: 2px solid transparent;
}

.plan-card:hover {
  transform: translateY(-5px);
  box-shadow: 0 10px 15px rgba(0, 0, 0, 0.1) !important;
}

.plan-card.selected {
  border: 2px solid #ff9800;
  box-shadow: 0 0 0 3px rgba(79, 70, 229, 0.2) !important;
}

.features-list li.disabled {
  color: #cbd5e0;
  text-decoration: line-through;
}

.select-btn {
  transition: all 0.3s;
}

.plan-card:hover .select-btn {
  background-color: #ff9800 !important;
  color: white !important;
}

.plan-card.selected .select-btn {
  background-color: #ff9800 !important;
  color: white !important;
}

.payment-option {
  transition: all 0.3s;
}

.payment-option:hover {
  border-color: #ff9800 !important;
}

.payment-option.active {
  border: 1px solid #ff9800 !important;
  background-color: rgba(255, 152, 0, 0.1) !important;
}

.payment-btn {
  transition: all 0.3s;
}

.payment-btn:disabled {
  background-color: #e2e8f0;
  color: #a0aec0;
  cursor: not-allowed;
}

.plan-card.bronze {
  border-top: 4px solid #cd7f32;
}

.plan-card.silver {
  border-top: 4px solid #c0c0c0;
}

.plan-card.gold {
  border-top: 4px solid #ffd700;
}

@media (max-width: 768px) {
  .plans-container {
    grid-template-columns: 1fr;
  }
}
</style>